@@ -24,6 +24,17 @@ function openstack_bootstrap_preprocess_page(&$variables) {
   }
 }
 
+/**
+ * Implements hook_preprocess_field().
+ */
+function openstack_bootstrap_preprocess_field(&$variables, $hook) {
+  if ($node = menu_get_object()) {
+    if (($node->type == 'group') && ($variables['field_name_css'] == 'field-group-status')) {
+      $status = $node->field_group_status[LANGUAGE_NONE][0]['value'] == 1;
+      $variables['items'][0]['#markup'] = $status ? '<div class="group-status-logo"></div>'.t('Official user group') : '';
+    }
+  }
+}
 
 /**
  * Implements hook_page_alter().
@@ -189,6 +200,11 @@ function openstack_bootstrap_preprocess_node(&$variables, $hook) {
       unset($variables['content']['links']['flag']['#links']['flag-inappropriate_node']);
     }
   }
+  // Add group-status-[official|unsupported] class to css
+  if ($node->type == 'group') {
+    $status = $node->field_group_status[LANGUAGE_NONE][0]['value'] == 1;
+    $variables['classes_array'][] = $status ? 'group-status-official' : 'group-status-unsupported';
+  }
   // Remove Log in or register from comments
   openstack_bootstrap_preprocess_comment($variables);
 }
@@ -212,4 +228,25 @@ function openstack_bootstrap_preprocess_views_view(&$variables) {
   if (strpos($view->name, 'commons_bw_') !== false) {
     $variables['exposed'] = '';
   }
+}
+
+/**
+ * Implements template_preprocess_user_profile()
+ */
+function openstack_bootstrap_preprocess_user_profile(&$variables) {
+  $account = $variables['elements']['#account'];
+  if (in_array('ambassador', $account->roles)) {
+    $variables['user_profile']['role_ambassador'] = array(
+      '#prefix' => '<span class="label label-info">',
+      '#markup' => t('Ambassador'),
+      '#suffix' => '</span>',
+    );
+  }
+  if (in_array('community_manager', $account->roles)) {
+    $variables['user_profile']['role_community_manager'] = array(
+      '#prefix' => '<span class="label label-info">',
+      '#markup' => t('Community Manager'),
+      '#suffix' => '</span>',
+    );
+  }
 }
\ No newline at end of file
